==> gridsite.0.2.1.tgz: gridsite/gridsite.h <==
/* 
  Copyright 2002 Andrew McNab mcnab@hep.man.ac.uk University of Manchester

  This file is part of GridSite.

  GridSite is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  GridSite is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with GridSite; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
*/

/*------------------------------------------------------------------------*
 * For more information about GridSite: http://www.gridpp.ac.uk/gridsite/ *
 *------------------------------------------------------------------------*/

/* defines and declarations common to all GridSite installations */

#define GRST_VERSION "0.2.1"

/* relative URL's of the LOCAL website help/status pages */

#define GRST_WEBSITE  "/website/"
#define GRST_STATUS   "/website/status/"
#define GRST_GROUPS   "/website/groups/"
#define GRST_MEMBERS  "/website/members/"

/* special groups */

#define GRST_ADDMBRS  "addmembers"
#define GRST_EDITMBRS "webadmin"
#define GRST_EDITGRPS "webadmin"
#define GRST_EDITDIRS "webadmin"

/* Databases of groups and members known by GridSite, 
   relative to DOCUMENT_ROOT (<-- which MAY or MAY NOT end in a / !!!) */
#define GRST_ETCGROUPS  "/../etc/groups/"
#define GRST_ETCMEMBERS "/../etc/members/"

/* MIME configuration */

#define GRST_ETCMIME     "/etc/mime.types"
#define GRST_DEFAULTMIME "application/octet-stream"

/* file we look for when asked for / */
#define GRST_INDEXHTML "index.html"

/* which syslog facility to we use (ideally, want one to ourselves) */
#define GRST_LOGLOCAL LOG_LOCAL3

/* Access Control List files in each directory */
#define GRST_ACL_FILE  ".grid-acl"

/* filename of header file, either in current directory or one of its
   parents */

#define GRST_HEADFILE "gridsitehead.txt"
#define GRST_FOOTFILE "gridsitefoot.txt"

/* maxima and lengths for various variables */

#define GRST_MAXGROUPS 100
#define GRST_GROUPLEN   20
#define GRST_DNLEN     100
#define GRST_ROLELEN    20
#define GRST_NAMELEN    30
#define GRST_EMAILLEN   30
#define GRST_ORGLEN     30
#define GRST_URLLEN     80

/* meaning of ACL flags for a given directory or group*/

#define GRID_ACL_NONE     0
#define GRID_ACL_READ     1
#define GRID_ACL_LIST     2
#define GRID_ACL_WRITE    3
#define GRID_ACL_ADMIN    4

/* wildcard to allow anyone access (including people with no DN) */
#define GRID_ACL_ANY_DN   "ANY_DN"

struct grst_member { char name[GRST_NAMELEN+1];
                     char email[GRST_EMAILLEN+1];
                     char organisation[GRST_ORGLEN+1];
                     char passcode[81];
                     char url[GRST_URLLEN+1]; 
                     char addedby[GRST_DNLEN+1];
                   };

==> gridsite.0.3.0.tgz: gridsite/gridsite.h <==
/* 
  Copyright 2002 Andrew McNab mcnab@hep.man.ac.uk University of Manchester

  This file is part of GridSite.

  GridSite is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  GridSite is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with GridSite; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
*/

/*------------------------------------------------------------------------*
 * For more information about GridSite: http://www.gridpp.ac.uk/gridsite/ *
 *------------------------------------------------------------------------*/

/* defines and declarations common to all GridSite installations */

#define GRST_VERSION "0.3.0"

/* relative URL's of the LOCAL website help/status pages */

#define GRST_WEBSITE    "/website/"
#define GRST_STATUS     "/website/status/"
#define GRST_GROUPS     "/website/groups/"
#define GRST_GROUPSINFO "/website/groupsinfo/"
#define GRST_MEMBERS    "/website/members/"

/* special groups */

#define GRST_ADDMBRS  "addmembers"
#define GRST_EDITMBRS "webadmin"
#define GRST_EDITGRPS "webadmin"
#define GRST_EDITDIRS "webadmin"

/* Databases of groups and members known by GridSite, 
   relative to DOCUMENT_ROOT (<-- which MAY or MAY NOT end in a / !!!) */
#define GRST_ETCGROUPS  "/../etc/groups/"
#define GRST_ETCMEMBERS "/../etc/members/"
#define GRST_ETCPROXIES "/../etc/proxies/"

#define GRST_GRIDPROXYINFO "/opt/globus/bin/grid-proxy-info"

#define GRST_ETCCONF    "/../etc/gridsite.conf"

/* tmp dir for creating files and then (atomically) moving into etc dirs */
#define GRST_ETCTMP     "/../etc/tmp/"

/* MIME configuration */

#define GRST_ETCMIME     "/etc/mime.types"
#define GRST_DEFAULTMIME "application/octet-stream"

/* file we look for when asked for / */
#define GRST_INDEXHTML "index.html"

/* which syslog facility to we use (ideally, want one to ourselves) */
#define GRST_LOGLOCAL LOG_LOCAL3

/* Access Control List files in each directory */
#define GRST_ACL_FILE  ".grid-acl"

/* filename of header file, either in current directory or one of its
   parents */

#define GRST_HEADFILE "gridsitehead.txt"
#define GRST_FOOTFILE "gridsitefoot.txt"

#define GRST_HEADFILE_PRINT "gridsiteheadprint.txt"
#define GRST_FOOTFILE_PRINT "gridsitefootprint.txt"

/* maxima and lengths for various variables */

#define GRST_MAXGROUPS 100
#define GRST_GROUPLEN   20
#define GRST_DNLEN     100
#define GRST_ROLELEN    20
#define GRST_DEFMAXLEN  80

/* meaning of ACL flags for a given directory or group*/

#define GRID_ACL_NOACL   -1
#define GRID_ACL_NONE     0
#define GRID_ACL_READ     1
#define GRID_ACL_LIST     2
#define GRID_ACL_WRITE    3
#define GRID_ACL_ADMIN    4

/* wildcard to allow anyone access (including people with no DN) */
#define GRID_ACL_ANY_DN   "ANY_DN"
